Class: Hecks::Bluebook::MetaValidator::Plan::Setter

Inherits:
Struct
  • Object
show all
Defined in:
lib/hecks/bluebook/meta_validator/plan.rb

Overview

One setting command. targets is target -> argument ; Lifecycle sets two fields in a single command, so it is a map rather than a pair.

Instance Attribute Summary collapse

Instance Attribute Details

#targetsObject

Returns the value of attribute targets

Returns:

  • (Object)

    the current value of targets



42
43
44
# File 'lib/hecks/bluebook/meta_validator/plan.rb', line 42

def targets
  @targets
end

#verbObject

Returns the value of attribute verb

Returns:

  • (Object)

    the current value of verb



42
43
44
# File 'lib/hecks/bluebook/meta_validator/plan.rb', line 42

def verb
  @verb
end